@@ -1,11 +1,15 @@
 import hashlib
 import json
-from datetime import date, datetime
+from datetime import date, datetime, timedelta
 
 import certifi
 import requests
 
-from juriscraper.lib.date_utils import fix_future_year_typo, json_date_handler
+from juriscraper.lib.date_utils import (
+    fix_future_year_typo,
+    json_date_handler,
+    make_date_range_tuples,
+)
 from juriscraper.lib.exceptions import InsanityException
 from juriscraper.lib.html_utils import (
     clean_html,
@@ -15,6 +19,7 @@ from juriscraper.lib.html_utils import (
     set_response_encoding,
 )
 from juriscraper.lib.log_tools import make_default_logger
+from juriscraper.lib.network_utils import SSLAdapter
 from juriscraper.lib.string_utils import (
     CaseNameTweaker,
     clean_string,
@@ -33,7 +38,7 @@ class AbstractSite:
     Should not contain lists that can't be sorted by the _date_sort function.
     """
 
-    def __init__(self, cnt=None):
+    def __init__(self, cnt=None, **kwargs):
         super().__init__()
 
         # Computed metadata
@@ -47,15 +52,33 @@ class AbstractSite:
         self.request = {
             "verify": certifi.where(),
             "session": requests.session(),
-            "headers": {"User-Agent": "Juriscraper"},
-            # Disable CDN caching on sites like SCOTUS (ahem)
-            "cache-control": "no-cache, no-store, max-age=1",
+            "headers": {
+                "User-Agent": "Juriscraper",
+                # Disable CDN caching on sites like SCOTUS (ahem)
+                "Cache-Control": "no-cache, max-age=0, must-revalidate",
+                # backwards compatibility with HTTP/1.0 caches
+                "Pragma": "no-cache",
+            },
             "parameters": {},
             "request": None,
             "status": None,
             "url": None,
         }
 
+        # Attribute to reference a function passed by the caller,
+        # which takes a single argument, the Site object, after
+        # each GET or POST request. Intended for saving the response for
+        # debugging purposes.
+        self.save_response = kwargs.get("save_response_fn")
+
+        # Some courts will block Juriscraper or Courtlistener's user-agent
+        # or may need special headers. This flag let's the caller know it
+        # should use the modified `self.request["headers"]`
+        self.needs_special_headers = False
+
+        # indicates whether the scraper should have results or not to raise an error
+        self.should_have_results = False
+
         # Sub-classed metadata
         self.court_id = None
         self.url = None
@@ -113,12 +136,20 @@ class AbstractSite:
         """
         self.request["verify"] = False
 
+    def set_custom_adapter(self, cipher: str):
+        """Set Custom SSL/TLS Adapter for out of date court systems
+
+        :param cipher: The court required cipher
+        :return: None
+        """
+        self.request["session"].mount("https://", SSLAdapter(ciphers=cipher))
+
     def test_mode_enabled(self):
         return self.method == "LOCAL"
 
     def to_json(self):
         return json.dumps(
-            [item for item in self],
+            list(self),
             default=json_date_handler,
         )
 
@@ -215,7 +246,12 @@ class AbstractSite:
                 " lengths: %s" % (self.court_id, lengths)
             )
         if len(self.case_names) == 0:
-            logger.warning(f"{self.court_id}: Returned with zero items.")
+            if self.should_have_results:
+                logger.error(
+                    f"{self.court_id}: Returned with zero items, but should have results."
+                )
+            else:
+                logger.warning(f"{self.court_id}: Returned with zero items.")
         else:
             for field in self._req_attrs:
                 if self.__getattribute__(field) is None:
@@ -223,17 +259,16 @@ class AbstractSite:
                         "%s: Required fields do not contain any data: %s"
                         % (self.court_id, field)
                     )
-            i = 0
             prior_case_name = None
-            for name in self.case_names:
+            for i, name in enumerate(self.case_names):
                 if not name.strip():
                     raise InsanityException(
                         "Item with index %s has an empty case name. The prior "
                         "item had case name of: %s" % (i, prior_case_name)
                     )
                 prior_case_name = name
-                i += 1
 
+        future_date_count = 0
         for index, case_date in enumerate(self.case_dates):
             if not isinstance(case_date, date):
                 raise InsanityException(
@@ -243,29 +278,43 @@ class AbstractSite:
                 )
             # Sanitize case date, fix typo of current year if present
             fixed_date = fix_future_year_typo(case_date)
+            case_name = self.case_names[index]
             if fixed_date != case_date:
                 logger.info(
                     "Date year typo detected. Converting %s to %s "
-                    "for case '%s' in %s"
-                    % (
-                        case_date,
-                        fixed_date,
-                        self.case_names[index],
-                        self.court_id,
-                    )
+                    "for case '%s' in %s",
+                    case_date,
+                    fixed_date,
+                    case_name,
+                    self.court_id,
                 )
                 case_date = fixed_date
                 self.case_dates[index] = fixed_date
-            if case_date.year > 2025:
-                raise InsanityException(
-                    "%s: member of case_dates list is from way in the future, "
-                    "with value %s" % (self.court_id, case_date.year)
-                )
 
-        # Is cookies a dict?
-        if type(self.cookies) != dict:
+            # If a date is approximate, then it may be set in the future until
+            # half of the year has passed. Ignore this case
+            if hasattr(self, "date_filed_is_approximate"):
+                date_is_approximate = self.date_filed_is_approximate[index]
+            else:
+                date_is_approximate = False
+
+            # dates should not be in the future. Tolerate a week
+            if not date_is_approximate and case_date > (
+                date.today() + timedelta(days=7)
+            ):
+                future_date_count += 1
+                error = f"{self.court_id}: {case_date} date is in the future. Case '{case_name}'"
+                logger.error(error)
+
+                # Interrupt data ingestion if more than 1 record has a bad date
+                if future_date_count > 1:
+                    raise InsanityException(
+                        f"More than 1 case has a date in the future. Last case: {error}"
+                    )
+
+        if not isinstance(self.cookies, dict):
             raise InsanityException(
-                "self.cookies not set to be a dict by " "scraper."
+                "self.cookies not set to be a dict by scraper."
             )
         logger.info(
             "%s: Successfully found %s items."
@@ -305,8 +354,10 @@ class AbstractSite:
         """
         return get_html_parsed_text(text)
 
-    def _download(self, request_dict={}):
+    def _download(self, request_dict=None):
         """Download the latest version of Site"""
+        if request_dict is None:
+            request_dict = {}
         self.downloader_executed = True
         if self.method == "POST":
             truncated_params = {}
@@ -318,13 +369,16 @@ class AbstractSite:
             )
         else:
             logger.info(f"Now downloading case page at: {self.url}")
+
         self._process_request_parameters(request_dict)
-        if self.method == "GET":
+
+        if self.test_mode_enabled():
+            self._request_url_mock(self.url)
+        elif self.method == "GET":
             self._request_url_get(self.url)
         elif self.method == "POST":
             self._request_url_post(self.url)
-        elif self.test_mode_enabled():
-            self._request_url_mock(self.url)
+
         self._post_process_response()
         return self._return_response_text_object()
 
@@ -337,12 +391,14 @@ class AbstractSite:
         """
         pass
 
-    def _process_request_parameters(self, parameters={}):
+    def _process_request_parameters(self, parameters=None):
         """Hook for processing injected parameter overrides"""
+        if parameters is None:
+            parameters = {}
         if parameters.get("verify") is not None:
             self.request["verify"] = parameters["verify"]
             del parameters["verify"]
-        self.request["parameters"] = parameters
+        self.request["parameters"].update(parameters)
 
     def _request_url_get(self, url):
         """Execute GET request and assign appropriate request dictionary
@@ -356,6 +412,8 @@ class AbstractSite:
             timeout=60,
             **self.request["parameters"],
         )
+        if self.save_response:
+            self.save_response(self)
 
     def _request_url_post(self, url):
         """Execute POST request and assign appropriate request dictionary values"""
@@ -368,6 +426,8 @@ class AbstractSite:
             timeout=60,
             **self.request["parameters"],
         )
+        if self.save_response:
+            self.save_response(self)
 
     def _request_url_mock(self, url):
         """Execute mock request, used for testing"""
@@ -389,17 +449,20 @@ class AbstractSite:
             else:
                 try:
                     payload = self.request["response"].content.decode("utf8")
-                except:
+                except Exception:
                     payload = self.request["response"].text
 
                 text = self._clean_text(payload)
                 html_tree = self._make_html_tree(text)
-                html_tree.rewrite_links(
-                    fix_links_in_lxml_tree, base_href=self.request["url"]
-                )
+                if hasattr(html_tree, "rewrite_links"):
+                    html_tree.rewrite_links(
+                        fix_links_in_lxml_tree, base_href=self.request["url"]
+                    )
                 return html_tree
 
-    def _get_html_tree_by_url(self, url, parameters={}):
+    def _get_html_tree_by_url(self, url, parameters=None):
+        if parameters is None:
+            parameters = {}
         self._process_request_parameters(parameters)
         self._request_url_get(url)
         self._post_process_response()
@@ -407,10 +470,59 @@ class AbstractSite:
         tree.make_links_absolute(url)
         return tree
 
-    def _download_backwards(self):
+    def _download_backwards(self, d):
         # methods for downloading the entire Site
         pass
 
+    def make_backscrape_iterable(
+        self, kwargs: dict
+    ) -> list[tuple[date, date]]:
+        """Creates back_scrape_iterable in the most common variation,
+        a list of tuples containing (start, end) date pairs, each of
+        `days_interval` size
+
+        Uses default attributes of the scrapers as a fallback, if
+        expected keyword arguments are not passed in the kwargs input
+
+        :param kwargs: if the following keys are present, use them
+            backscrape_start: str in "%Y/%m/%d" format ;
+                            Default: self.first_opinion_date
+            backscrape_end: str
+            days_interval: int; Default: self.days_interval
+
+        :return: None; sets self.back_scrape_iterable in place
+        """
+        start = kwargs.get("backscrape_start")
+        end = kwargs.get("backscrape_end")
+        days_interval = kwargs.get("days_interval")
+
+        if start:
+            start = datetime.strptime(start, "%Y/%m/%d").date()
+        else:
+            if hasattr(self, "first_opinion_date"):
+                start = self.first_opinion_date
+            else:
+                logger.warning(
+                    "No `backscrape_start` argument passed; and scraper has no `first_opinion_date` default"
+                )
+
+        if end:
+            end = datetime.strptime(end, "%Y/%m/%d").date()
+        else:
+            end = datetime.now().date()
+
+        if not days_interval:
+            if hasattr(self, "days_interval"):
+                days_interval = self.days_interval
+            else:
+                logger.warning(
+                    "No `days_interval` argument passed; and scraper has no default"
+                )
+
+        self.back_scrape_iterable = make_date_range_tuples(
+            start, end, days_interval
+        )
+
     @staticmethod
     def cleanup_content(content):
         """
