@@ -11,6 +11,8 @@ class OpinionSite(AbstractSite):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
+        self.expected_content_types = ["application/pdf"]
+
         # Order of attributes is important as it affects the order of parsing.
         # Some methods rely on others having already been run.
         self._opt_attrs = [
@@ -23,6 +25,7 @@ class OpinionSite(AbstractSite):
             "docket_numbers",
             "judges",
             "lower_courts",
+            "lower_court_ids",
             "lower_court_judges",
             "lower_court_numbers",
             "nature_of_suit",
@@ -30,6 +33,14 @@ class OpinionSite(AbstractSite):
             "parallel_citations",
             "summaries",
             "case_name_shorts",
+            "child_courts",
+            "authors",
+            "joined_by",
+            "per_curiam",
+            "types",
+            "other_dates",
+            "attorneys",
+            "headnotes",
         ]
         self._req_attrs = [
             "case_dates",
@@ -94,6 +105,9 @@ class OpinionSite(AbstractSite):
     def _get_lower_courts(self):
         return None
 
+    def _get_lower_court_ids(self):
+        return None
+
     def _get_lower_court_judges(self):
         return None
 
@@ -108,7 +122,31 @@ class OpinionSite(AbstractSite):
     def _get_summaries(self):
         return None
 
-    def extract_from_text(self, scraped_text):
+    def _get_child_courts(self):
+        return None
+
+    def _get_authors(self):
+        return None
+
+    def _get_types(self):
+        return None
+
+    def _get_joined_by(self):
+        return None
+
+    def _get_per_curiam(self):
+        return None
+
+    def _get_other_dates(self):
+        return None
+
+    def _get_attorneys(self):
+        return None
+
+    def _get_headnotes(self):
+        return None
+
+    def extract_from_text(self, scraped_text: str) -> dict:
         """Pass scraped text into function and return data as a dictionary
 
         :param opinion_text: Text of scraped content
