@@ -1,29 +1,41 @@
 #!/usr/bin/env python
 import re
-import sys
+from copy import deepcopy
 from urllib.parse import urlsplit, urlunsplit
 
-import lxml
+import nh3
 from lxml import etree, html
-from lxml.etree import XMLSyntaxError
-from lxml.html import HtmlElement, fromstring, html5parser, tostring
-from lxml.html.clean import Cleaner
+from lxml.html import HtmlElement, fromstring, tostring
 from requests import Response
 
 try:
-    # Use cchardet for performance to detect the character encoding.
-    import cchardet as chardet
+    # Use charset-normalizer for performance to detect the character encoding.
+    import charset_normalizer as chardet
 except ImportError:
     import chardet
 
-if sys.maxunicode == 65535:
-    from .log_tools import make_default_logger
+ALLOWED_ATTRIBUTES = deepcopy(nh3.ALLOWED_ATTRIBUTES)
+ALLOWED_ATTRIBUTES["a"].update({"id", "onclick"})
+ALLOWED_ATTRIBUTES["div"] = {"class", "id"}
+ALLOWED_ATTRIBUTES["font"] = {"face", "size"}
+ALLOWED_ATTRIBUTES["form"] = {"name", "method", "action"}
+ALLOWED_ATTRIBUTES["input"] = {
+    "class",
+    "id",
+    "name",
+    "value",
+    "type",
+    "onclick",
+}
+ALLOWED_ATTRIBUTES["span"] = {"class"}
+ALLOWED_ATTRIBUTES["table"].update({"border", "class"})
+ALLOWED_ATTRIBUTES["tr"].add("class")
 
-    logger = make_default_logger()
-    logger.warning(
-        "You are using a narrow build of Python, which is not "
-        "completely supported. See issue #188 for details."
-    )
+ALLOWED_TAGS = deepcopy(nh3.ALLOWED_TAGS)
+ALLOWED_TAGS.add("font")
+ALLOWED_TAGS.add("form")
+ALLOWED_TAGS.add("input")
+ALLOWED_TAGS.add("script")
 
 
 def get_xml_parsed_text(text):
@@ -41,18 +53,21 @@ def get_html_from_element(element):
 def get_html5_parsed_text(text: str) -> HtmlElement:
     """Return content using the html5parser, ideal for faulty html.
 
-    This dance is slightly different than usual because it uses the
-    html5parser to first create an _Element object, then serialize it using
-    `tostring`, then parse *that* using the usual fromstring function. The
-    end result is that irregularities in the html are fixed by the
-    html5parser, and the usual lxml parser gives us the same API we are
-    used to.
+    This first uses nh3 to sanitize the html before parsing it with
+    the usual lxml parser.
 
     :param text: The html of the document
     :return: an lxml.HtmlElement object
     """
-    parsed = html5parser.document_fromstring(text)
-    return fromstring(tostring(parsed, encoding="unicode"))
+    return fromstring(
+        nh3.clean(
+            text,
+            strip_comments=False,
+            attributes=ALLOWED_ATTRIBUTES,
+            clean_content_tags=set(),
+            tags=ALLOWED_TAGS,
+        )
+    )
 
 
 def get_table_column_text(
@@ -102,20 +117,6 @@ def get_row_column_links(row, cell_num):
     return row.xpath(".//td[%d]//a/@href" % cell_num)[0]
 
 
-def get_clean_body_content(content, remove_extra_tags=[]):
-    """Parse out the body from an html string, clean it up, and send it along."""
-    remove_tags = ["a", "body", "font", "noscript"]
-    remove_tags.extend(remove_extra_tags)
-    cleaner = Cleaner(style=True, remove_tags=remove_tags)
-    try:
-        return cleaner.clean_html(content)
-    except XMLSyntaxError:
-        return (
-            "Unable to extract the content from this file. Please try "
-            "reading the original."
-        )
-
-
 def strip_bad_html_tags_insecure(
     text: str, remove_scripts=True
 ) -> HtmlElement:
@@ -131,44 +132,27 @@ def strip_bad_html_tags_insecure(
     :return: the cleaned HTML tree
     """
 
-    assert isinstance(
-        text, str
-    ), f"`text` must be of type str, but is of type {type(text)}."
+    assert isinstance(text, str), (
+        f"`text` must be of type str, but is of type {type(text)}."
+    )
 
-    # lxml fails to parse a script element that contains a '<' followed by any
-    # non-space character e.g: '<ca.length' which causes breakage. Removing
-    # script elements with this problem through lxml will cause all the
-    # following elements are also removed. To avoid this issue first remove
-    # all the script elements using regex before removing the script tags.
-    # See: jpml_1551542
+    clean_content_tags = {"style"}
     if remove_scripts:
-        text = re.sub(r"<script.*?>([\s\S]*?)<\/script>", "", text)
+        clean_content_tags.add("script")
+        tags = deepcopy(ALLOWED_TAGS)
+        tags.remove("script")
+    else:
+        tags = ALLOWED_TAGS
 
-    # Cleaner() can work with strs and unicode, but it does bad things to
-    # encodings if given the chance.
-    tree = get_html5_parsed_text(text)
-    cleaner = Cleaner(
-        # Keep JS: We parse onclicks for pacer metadata
-        javascript=False,
-        safe_attrs_only=False,
-        # Keep forms: We parse them for metadata
-        forms=False,
-        # Keep comments: We use them in appellate PACER. For discussion and fix
-        # to funky workaround below, see:
-        #   https://bugs.launchpad.net/lxml/+bug/1882606
-        # This workaround can be removed once lxml 4.5.2 is released
-        comments=False,
-        processing_instructions=False,
-        remove_unknown_tags=False,
-        allow_tags=set(lxml.html.defs.tags) | {lxml.etree.Comment},
-        # Things we *can* actually remove
-        scripts=remove_scripts,
-        style=True,
-        links=True,
-        embedded=True,
-        frames=True,
+    return fromstring(
+        nh3.clean(
+            text,
+            strip_comments=False,
+            attributes=ALLOWED_ATTRIBUTES,
+            clean_content_tags=clean_content_tags,
+            tags=tags,
+        )
     )
-    return cleaner.clean_html(tree)
 
 
 def get_visible_text(html_content):
@@ -185,7 +169,7 @@ def get_visible_text(html_content):
 def set_response_encoding(request):
     """Set the encoding if it isn't set already.
 
-    Use cchardet for added performance.
+    Use charset-normalizer for added performance.
     """
     if request:
         # If the encoding is iso-8859-1, switch it to cp1252 (a superset)
@@ -194,12 +178,13 @@ def set_response_encoding(request):
 
         if request.encoding is None:
             # Requests detects the encoding when the item is GET'ed using
-            # HTTP headers, and then when r.text is accessed, if the encoding
-            # hasn't been set by that point. By setting the encoding here, we
-            # ensure that it's done by cchardet, if it hasn't been done with
-            # HTTP headers. This way it is done before r.text is accessed
-            # (which would do it with vanilla chardet). This is a big
-            # performance boon, and can be removed once requests is upgraded
+            # HTTP headers, and then when r.text is accessed, if the
+            # encoding hasn't been set by that point. By setting the
+            # encoding here, we ensure that it's done by charset-normalizer,
+            # if it hasn't been done with HTTP headers. This way it is done
+            # before r.text is accessed (which would do it with vanilla
+            # chardet). This is a big performance boon, and can be removed
+            # once requests is upgraded
             if isinstance(request.content, str):
                 as_bytes = request.content.encode()
                 request.encoding = chardet.detect(as_bytes)["encoding"]
@@ -234,20 +219,12 @@ def clean_html(text: str) -> str:
         text = re.sub(r"&#0[1-8]\b|&#[1-8]\b", "", text)
 
     # Fix invalid bytes in XML (http://stackoverflow.com/questions/8733233/)
-    # Note that this won't work completely on narrow builds of Python, which
-    # existed prior to Py3. Thus, we check if it's a narrow build, and adjust
-    # accordingly.
-    if sys.maxunicode == 65535:
-        text = re.sub(
-            "[^\u0020-\uD7FF\u0009\u000A\u000D\uE000-\uFFFD]+", "", text
-        )
-    else:
-        text = re.sub(
-            "[^\u0020-\uD7FF\u0009\u000A\u000D\uE000-\uFFFD"
-            "\U00010000-\U0010FFFF]+",
-            "",
-            text,
-        )
+    text = re.sub(
+        "[^\u0020-\ud7ff\u0009\u000a\u000d\ue000-\ufffd"
+        "\U00010000-\U0010ffff]+",
+        "",
+        text,
+    )
 
     return text
 
@@ -299,6 +276,4 @@ def fix_links_in_lxml_tree(link, keep_anchors=False):
 def is_html(response: Response) -> bool:
     """Determines whether the item downloaded is an HTML document or something
     else."""
-    if "text/html" in response.headers.get("content-type", ""):
-        return True
-    return False
+    return "text/html" in response.headers.get("content-type", "")
