@@ -6,6 +6,7 @@ Reviewer: mlr
 Date created: 1 Sep 2014
 Type: Precedential
 """
+
 import json
 
 from juriscraper.OpinionSiteLinear import OpinionSiteLinear
@@ -18,10 +19,12 @@ class Site(OpinionSiteLinear):
         self.status = "Published"
         self.url = "https://www.mspb.gov/decisions/precedential/PrecedentialDecisions_Manifest_Table.json"
         self.base = "https://www.mspb.gov/decisions/precedential"
+        self.should_have_results = True
 
     def _process_html(self):
         if self.test_mode_enabled():
-            self.html = json.load(open(self.url))
+            with open(self.url) as file:
+                self.html = json.load(file)
         for row in self.html["data"]:
             url = row["FILE_NAME"]
             name = f"{row['APL_FIRST_NAME']} {row['APL_LAST_NAME']} v. {row['AGENCY']}"
