@@ -4,6 +4,8 @@ __all__ = [
     "alacrimapp",
     "alaska",
     "alaskactapp",
+    "alaska_slip",
+    "alaska_u",
     "ariz",
     "arizctapp_div_1",
     "arizctapp_div_2",
@@ -31,20 +33,16 @@ __all__ = [
     "delctcompl",
     "delsuperct",
     "fla",
-    "fladistctapp_1_per_curiam",
-    "fladistctapp_1_written",
-    "fladistctapp_2_per_curiam",
-    "fladistctapp_2_written",
+    "fladistctapp_1",
+    "fladistctapp_2",
     "fladistctapp_3",
-    "fladistctapp_4_pc",
-    "fladistctapp_4_written",
+    "fladistctapp_4",
     "fladistctapp_5",
+    "fladistctapp_6",
     "ga",
     "gactapp",
     "haw",
-    "haw_beginningofyear",
     "hawapp",
-    "hawapp_beginningofyear",
     "idaho_civil",
     "idaho_criminal",
     "idahoctapp_civil",
@@ -54,21 +52,24 @@ __all__ = [
     "illappct",
     "ind",
     "indctapp",
+    "indctapp_reclassified",
     "indtc",
     "iowa",
     "iowactapp",
-    "kan_p",
-    "kan_u",
-    "kanctapp_p",
-    "kanctapp_u",
+    "kan",
+    "kanctapp",
     "ky",
     "kyctapp",
     "la",
     "lactapp_1",
+    "lactapp_2",
+    "lactapp_4",
+    "lactapp_5",
     "mass",
     "massappct",
     "massappct_u",
     "masslandct",
+    "masssuperct",
     "md",
     "mdag",
     "mdctspecapp",
@@ -79,31 +80,39 @@ __all__ = [
     # that. It will also be worth considering whether the scraper itself
     # should be re-written to scrape CourtListener's API instead of the
     # court's website.
-    # "me",
+    "me",
+    "mesuperct",
     "mich",
     "michctapp",
     "minn",
     "minnag",
-    "minnctapp",
-    "miss",
-    "missctapp",
-    "mo",
-    "moctapp_eastern",
-    "moctapp_southern",
-    "moctapp_western",
+    "minnctapp_p",
+    "minnctapp_u",
+    # These courts are uploaded via portal by amazing volunteers.
+    # "miss",
+    # "missctapp",
+    # "mo",
+    # "moctapp_eastern",
+    # "moctapp_southern",
+    # "moctapp_western",
     "mont",
     "nc",
     "ncctapp",
     "neb",
     "nebctapp",
     "nd",
-    "nev_p",
-    "nev_u",
-    "nh",
+    "nev",
+    "nevapp",
+    "nh_p",
+    "nh_u",
     "nm",
     "nmctapp",
     "nj",
-    "njsuperctappdiv",
+    "njsuperctappdiv_p",
+    "njsuperctappdiv_u",
+    "njtaxct_p",
+    "njtaxct_u",
+    "njsuperctappdiv_u",
     "ny",
     "nyag",
     "nyappdiv_1st",
@@ -112,7 +121,17 @@ __all__ = [
     "nyappdiv_4th",
     "nyappterm_1st",
     "nyappterm_2nd",
+    "nysupct_commercial",
     "nysupct",
+    "nyfamct",
+    "nycityct",
+    "nycountyct",
+    "nycivct",
+    "nycrimct",
+    "nysurct",
+    "nydistct",
+    "nyjustct",
+    "nyclaimsct",
     "ohio",
     "ohioctapp_1",
     "ohioctapp_2",
@@ -129,6 +148,8 @@ __all__ = [
     "ohioctcl",
     "ohioctcl_beginningofyear",
     "or",
+    "orctapp",
+    "ortc",
     "okla",
     "oklaag",
     "oklacivapp",
@@ -136,11 +157,12 @@ __all__ = [
     "pa",
     "pacommwct",
     "pasuperct",
-    "ri_p",
-    "ri_u",
+    "ri",
     "sd",
     "sc",
+    "sc_u",
     "scctapp",
+    "scctapp_u",
     "tenn",
     "tennctapp",
     "tenncrimapp",
@@ -160,6 +182,8 @@ __all__ = [
     "texapp_12",
     "texapp_13",
     "texapp_14",
+    "texapp_15",
+    "texbizct",
     "texcrimapp",
     "utah",
     "utahctapp",
@@ -167,8 +191,8 @@ __all__ = [
     "vactapp_u",
     "vactapp_p",
     "vt",
+    "vt_criminal",
     "vtsuperct_civil",
-    "vtsuperct_criminal",
     "vtsuperct_environmental",
     "vtsuperct_family",
     "vtsuperct_probate",
@@ -176,6 +200,7 @@ __all__ = [
     "washctapp_p",
     "washctapp_u",
     "wis",
+    "wisctapp",
     "wva",
     "wvactapp",
     "wyo",
