@@ -3,7 +3,7 @@
 # Court Short Name: ga
 
 import re
-from datetime import date, datetime, timedelta
+from datetime import date
 
 from juriscraper.AbstractSite import logger
 from juriscraper.lib.string_utils import titlecase
@@ -11,21 +11,15 @@ from juriscraper.OpinionSiteLinear import OpinionSiteLinear
 
 
 class Site(OpinionSiteLinear):
+    url_template = "https://www.gasupreme.us/opinions/{}-opinions/"
+    first_opinion_year = 2017
+
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.court_id = self.__module__
-        today = date.today()
-        self.url = self._get_url(today.year)
+        self.url = self.url_template.format(date.today().year)
         self.status = "Published"
-        self.back_scrape_iterable = range(2016, 2022)
-
-    def _get_url(self, year: int) -> str:
-        """Generate the GA URL for a given year.
-
-        :param year: Year to scrape
-        :return: URL for the given year
-        """
-        return f"https://www.gasupreme.us/opinions/{year}-opinions/"
+        self.make_backscrape_iterable(kwargs)
 
     def _process_html(self) -> None:
         for link in self.html.xpath("//li/a[contains(@href, '.pdf')]"):
@@ -34,12 +28,24 @@ class Site(OpinionSiteLinear):
             # - "S20A1505, S20A1506. PENDER v. THE STATE"
             # - "S21A0306. BELL v. RAFFENSPERGER"
             title = link.text_content()
+
             if not title:
+                logger.info("No link title for row %s", url)
                 continue
+
             dockets = re.findall(r"S?\d{2}\w\d{4}", title)
             if not dockets:
+                # Try this only when the <a> doesn't include the docket;
+                # if done always, may pick up extra info like
+                # "Reinstatement issued" or "Concurral issued"
+                title = link.xpath("string(..)")
+                dockets = re.findall(r"S?\d{2}\w\d{4}", title)
+
+            if not dockets or "SUMMARY" in title:
                 # Skip links to weekly summaries or cases without a docket
+                logger.info("Skip summary row %s", title)
                 continue
+
             docket = ", ".join(dockets)
             name = title.split(dockets[-1])[-1].strip("., ")
             # Expected summary content:
@@ -47,7 +53,7 @@ class Site(OpinionSiteLinear):
             # - "July 7, 2021"
             # - "February 15, 2021 – SUMMARIES for NOTEWORTHY OPINIONS"
             summary = link.xpath(
-                ".//parent::li/parent::ul/preceding-sibling::p[1]"
+                ".//parent::li/parent::ul/preceding-sibling::h3[1]/following-sibling::p"
             )[0].text_content()
             # Character separator for dates from summary text could be:
             # - dash: "-"
@@ -56,7 +62,6 @@ class Site(OpinionSiteLinear):
             date_str = (
                 summary.split("–")[0].split("—")[0].split("-")[0].strip()
             )
-            date_summary = datetime.strptime(date_str, "%B %d, %Y")
             self.cases.append(
                 {
                     "date": date_str,
@@ -66,13 +71,35 @@ class Site(OpinionSiteLinear):
                 }
             )
 
-    def _download_backwards(self, year) -> None:
-        self.url = self._get_url(year)
-        logger.info(f"Backscraping for year {year}: {self.url}")
+    def _download_backwards(self, year: int) -> None:
+        self.url = self.url_template.format(year)
+        logger.info("Backscraping for year %s %s", year, self.url)
         self.html = self._download()
+        self._process_html()
 
-        # Setting status is important because it prevents the download
-        # function from being run a second time by the parse method.
-        if self.html is not None:
-            self.status = 200
-            self._process_html()
+    def make_backscrape_iterable(self, kwargs: dict):
+        if kwargs.get("backscrape_start"):
+            start = int(kwargs["backscrape_start"])
+        else:
+            start = self.first_opinion_year
+
+        if kwargs.get("backscrape_end"):
+            end = int(kwargs["backscrape_end"])
+        else:
+            end = date.today().year - 1
+
+        if start == end:
+            end = start + 1
+
+        self.back_scrape_iterable = range(start, end)
+
+    def extract_from_text(self, scraped_text: str) -> dict:
+        """Extract the state citation from the document's text
+
+        :param scraped_text: the extracted text
+        :return: a dictionary, empty or with expected Citation key
+        """
+        if match := re.search(r"\d+ Ga. \d+", scraped_text[:50]):
+            return {"Citation": match.group(0)}
+        else:
+            return {}
