@@ -9,4 +9,4 @@ class Site(haw.Site):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.court_id = self.__module__
-        self.target_id = "ICA"
+        self.court_code = "ICA"
