@@ -9,10 +9,17 @@ History:
   2022-01-21: Updated by satsuki-chan: Added validation when citation is missing.
 """
 
+import re
+from datetime import datetime
+
 from juriscraper.opinions.united_states.state import ill
 
 
 class Site(ill.Site):
+    days_interval = 10
+    first_opinion_date = datetime(1996, 9, 3)
+    court_filter = "All Appellate Court"
+
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.court_id = self.__module__
@@ -21,7 +28,12 @@ class Site(ill.Site):
         )
         self.docket_re = r"(?P<citation>\d{4}\s+IL App\s+(\((?P<district>\d+)\w{1,2}\)\s+)?(?P<docket>\d+\w{1,2})-?U?[BCD]?)"
 
-    def _get_docket(self, match):
+    def _get_docket(self, match: re.Match) -> str:
+        """Builds docket_number from a regex match
+
+        :param match: a regex match object
+        :return: docket_number
+        """
         raw_docket = match.group("docket")
         district = match.group("district")
         return f"{district}-{raw_docket[0:2]}-{raw_docket[2:]}"
