@@ -10,11 +10,11 @@ History:
     - Update 2023-01-28 by William E. Palin
 """
 
+from datetime import datetime
+
 from juriscraper.opinions.united_states.state import mass
 
 
 class Site(mass.Site):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.court_id = self.__module__
-        self.court_identifier = "AC"
+    court_name = "Appeals Court"
+    first_opinion_date = datetime(2017, 6, 15)
