@@ -5,8 +5,6 @@
 # Reviewer: mlr
 # Date: 2014-07-05
 
-from datetime import date
-
 from juriscraper.opinions.united_states.state import okla
 
 
@@ -14,7 +12,4 @@ class Site(okla.Site):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.court_id = self.__module__
-        d = date.today()
-        self.url = "http://www.oscn.net/applications/oscn/Index.asp?ftdb=STOKCSCV&year={year}&level=1".format(
-            year=d.year
-        )
+        self.url = "https://www.oscn.net/decisions/ok-civ-app/90"
