@@ -3,6 +3,9 @@ Scraper for the Tennessee Court of Criminal Appeals
 CourtID: tennctcrimapp
 Court Short Name: Tenn. Ct. Crim. App.
 """
+
+from datetime import datetime
+
 from juriscraper.opinions.united_states.state import tenn
 
 
@@ -11,6 +14,6 @@ class Site(tenn.Site):
         super().__init__(*args, **kwargs)
         self.court_id = self.__module__
         self.url = (
-            "http://www.tsc.state.tn.us/courts/court-criminal-appeals/opinions"
+            "https://www.tncourts.gov/courts/court-criminal-appeals/opinions"
         )
-        self.back_scrape_iterable = list(range(0, 1325))
+        self.first_opinion_date = datetime(1988, 12, 8)
