@@ -7,4 +7,4 @@ from juriscraper.opinions.united_states.state import wva
 class Site(wva.Site):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.url = "http://www.courtswv.gov/intermediate-court/opinions.html"
+        self.url = "https://www.courtswv.gov/appellate-courts/intermediate-court-of-appeals/opinions/prior-terms"
