@@ -13,21 +13,20 @@ class Site(cit.Site):
         self.court_id = self.__module__
 
     def _get_download_urls(self):
-        return [t for t in self.html.xpath("//table[4]//tr/td[1]//a/@href")]
+        return list(self.html.xpath("//table[4]//tr/td[1]//a/@href"))
 
     def _get_citations(self):
-        return [t for t in self.html.xpath("//table[4]//tr/td[1]//a/text()")]
+        return list(self.html.xpath("//table[4]//tr/td[1]//a/text()"))
 
     def _get_case_names(self):
         # Exclude confidential rows by ensuring there is a sibling row that
         # contains an anchor (which confidential cases do not)
         # There is also one stray case within a <p> tag we have to catch.
-        return [
-            s
-            for s in self.html.xpath(
+        return list(
+            self.html.xpath(
                 "//table[4]//tr[position() > 1]/td[2][../td//a]/text()[1] | //table[4]//tr[position() > 1]/td[2][../td//a]/p/text()[1]"
             )
-        ]
+        )
 
     def _get_precedential_statuses(self):
         return ["Published"] * len(self.case_names)
@@ -73,6 +72,4 @@ class Site(cit.Site):
         return judges
 
     def _get_nature_of_suit(self):
-        return [
-            t for t in self.html.xpath("//table[4]//tr/td[6][../td//a]/text()")
-        ]
+        return list(self.html.xpath("//table[4]//tr/td[6][../td//a]/text()"))
