@@ -5,9 +5,8 @@ Court Short Name: NY
 History:
  2015-10-27  Created by Andrei Chelaru
 """
-from datetime import date
 
-from dateutil.rrule import DAILY, rrule
+from datetime import date
 
 from juriscraper.opinions.united_states.state.nyappterm_1st import (
     Site as NySite,
@@ -15,16 +14,9 @@ from juriscraper.opinions.united_states.state.nyappterm_1st import (
 
 
 class Site(NySite):
+    first_opinion_date = date(2003, 10, 27)
+    days_interval = 180
+
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.interval = 200
-        self.back_scrape_iterable = [
-            i.date()
-            for i in rrule(
-                DAILY,
-                interval=self.interval,
-                dtstart=date(2003, 6, 1),
-                until=date(2016, 1, 1),
-            )
-        ]
         self.court = "Court of Appeals"
