@@ -3,13 +3,15 @@
 This is pretty limited metadata about the case, although it
 presents some more information for BK cases.
 """
+
 import pprint
 import re
 import sys
 
-from ..lib.log_tools import make_default_logger
-from ..lib.string_utils import clean_string, force_unicode, harmonize
-from ..lib.utils import clean_court_object
+from juriscraper.lib.log_tools import make_default_logger
+from juriscraper.lib.string_utils import clean_string, force_unicode, harmonize
+from juriscraper.lib.utils import clean_court_object
+
 from .docket_report import BaseDocketReport
 from .reports import BaseReport
 
@@ -134,11 +136,26 @@ class CaseQuery(BaseDocketReport, BaseReport):
         #   <B><FONT SIZE=+1>18-11572</FONT></B><B></B>Nancy Jean Stevens
         # We take the docket number from the <font> tag (the innermost tag),
         # although we could but have chosen the first <b> tag.
-        docket_number = self._parse_docket_number_strs(
-            [rows[0].find(".//font").text_content()]
+        docket_number, docket_number_components = (
+            self._parse_docket_number_strs(
+                [rows[0].find(".//font").text_content()]
+            )
         )
         # And case caption following the final <b></b> pair.
         case_name_raw = force_unicode(rows[0].find(".//b[last()]").tail or "")
+        if not case_name_raw:
+            # In some courts, such as INSB, the case name is within a font tag.
+            # <b><font size="+1">13-07422-RLM-7A</font></b><font size="+1">
+            #  Cedric Morris and Kateen Nicklondra Morris
+            # </font>
+            try:
+                case_name_raw = force_unicode(
+                    rows[0].xpath(
+                        ".//b[last()]/following-sibling::font[1]/text()"
+                    )[0]
+                )
+            except IndexError:
+                case_name_raw = ""
 
         # Our job as a parser is to return the data, not to filter, clean,
         # amend, or "harmonize" it. However downstream often expects harmonized
@@ -156,6 +173,7 @@ class CaseQuery(BaseDocketReport, BaseReport):
         field_names = {
             "date_of_last_filing": "date_last_filing",
             "judge": "assigned_to_str",
+            "chief_judge": "assigned_to_str",
             "plan_confirmed": "date_plan_confirmed",
             "debtor_discharged": "date_debtor_dismissed",
             "joint_debtor_discharged": "date_joint_debtor_dismissed",
@@ -202,6 +220,8 @@ class CaseQuery(BaseDocketReport, BaseReport):
                 "case_name_raw": case_name_raw,
             }
         )
+        # Include the docket_number components.
+        data.update(docket_number_components)
 
         data = clean_court_object(data)
 
@@ -254,12 +274,12 @@ class CaseQuery(BaseDocketReport, BaseReport):
          - The case_num parameter needs a value; any value will do.
          - As usual, the ?1-L_1_0-1 business in the URL is needed
         """
-        assert (
-            self.session is not None
-        ), "session attribute of CaseQuery report cannot be None."
-        assert bool(
-            pacer_case_id
-        ), f"pacer_case_id must be truthy, not '{pacer_case_id}'"
+        assert self.session is not None, (
+            "session attribute of CaseQuery report cannot be None."
+        )
+        assert bool(pacer_case_id), (
+            f"pacer_case_id must be truthy, not '{pacer_case_id}'"
+        )
         params = {
             "UserType": "",
             "all_case_ids": pacer_case_id,
