@@ -1,14 +1,16 @@
 import re
+from typing import Union
 
-from ..lib.judge_parsers import normalize_judge_string
-from ..lib.log_tools import make_default_logger
-from ..lib.string_utils import (
+from juriscraper.lib.judge_parsers import normalize_judge_string
+from juriscraper.lib.log_tools import make_default_logger
+from juriscraper.lib.string_utils import (
     clean_string,
     convert_date_string,
     force_unicode,
     harmonize,
 )
-from ..lib.utils import clean_court_object, previous_and_next
+from juriscraper.lib.utils import clean_court_object, previous_and_next
+
 from .docket_report import DocketReport
 from .utils import (
     get_nonce_from_form,
@@ -18,18 +20,22 @@ from .utils import (
 
 logger = make_default_logger()
 
-date_regex = r"[—\d\-–/]*"
-
 
 class DocketHistoryReport(DocketReport):
     assigned_to_regex = r"(.*),\s+presiding"
     referred_to_regex = r"(.*),\s+referral"
-    date_filed_regex = re.compile(r"[fF]iled:\s+(%s)" % date_regex)
+    date_filed_regex = re.compile(
+        r"[fF]iled:\s+(%s)" % DocketReport.DATE_REGEX
+    )
     date_last_filing_regex = re.compile(
-        r"last\s+filing:\s+(%s)" % date_regex, flags=re.IGNORECASE
+        r"last\s+filing:\s+(%s)" % DocketReport.DATE_REGEX,
+        flags=re.IGNORECASE,
     )
     date_filed_and_entered_regex = re.compile(
-        r"& Entered:\s+(%s)" % date_regex
+        r"& Entered:\s+(%s)" % DocketReport.DATE_REGEX
+    )
+    date_entered_regex = re.compile(
+        r"[eE]ntered:\s+(%s)" % DocketReport.DATE_REGEX
     )
 
     PATH = "cgi-bin/HistDocQry.pl"
@@ -52,9 +58,10 @@ class DocketHistoryReport(DocketReport):
             return self._metadata
 
         self._set_metadata_values()
+        docket_number, docket_number_components = self._parse_docket_number()
         data = {
             "court_id": self.court_id,
-            "docket_number": self._get_docket_number(),
+            "docket_number": docket_number,
             "case_name": self._get_case_name(),
             "date_filed": self._get_value(
                 self.date_filed_regex, self.metadata_values, cast_to_date=True
@@ -77,7 +84,8 @@ class DocketHistoryReport(DocketReport):
             "assigned_to_str": self._get_assigned_judge(),
             "referred_to_str": self._get_judge(self.referred_to_regex),
         }
-
+        # Include the docket_number components.
+        data.update(docket_number_components)
         data = clean_court_object(data)
         self._metadata = data
         return data
@@ -103,9 +111,9 @@ class DocketHistoryReport(DocketReport):
         :return: request response object
         """
         # Set up and sanity tests
-        assert (
-            self.session is not None
-        ), "session attribute of DocketHistoryReport cannot be None."
+        assert self.session is not None, (
+            "session attribute of DocketHistoryReport cannot be None."
+        )
 
         if query_type not in ["History", "Documents"]:
             raise ValueError("Invalid value for 'query_type' parameter.")
@@ -147,9 +155,9 @@ class DocketHistoryReport(DocketReport):
             return self._docket_entries
 
         docket_header = './/th/text()[contains(., "Description")]'
-        docket_entry_rows = self.tree.xpath(f"//table[{docket_header}]//tr")[
-            1:
-        ]  # Skip first row
+        docket_entry_rows = self.tree.xpath(
+            f"//table[{docket_header}]/tbody/tr"
+        )[1:]  # Skip first row
 
         docket_entries = []
         for row in docket_entry_rows:
@@ -174,14 +182,15 @@ class DocketHistoryReport(DocketReport):
                     de["pacer_doc_id"] = None
                     de["pacer_seq_no"] = None
                 de["date_filed"] = self._get_date_filed(cells[1])
+                de["date_entered"] = self._get_date_entered(cells[1])
                 de["short_description"] = force_unicode(
                     cells[2].text_content()
                 )
                 de["description"] = ""
                 docket_entries.append(de)
-            elif len(cells) == 1:
+            elif len(cells) in {1, 2}:
                 # Document long description. Get it, and add it to previous de.
-                desc = force_unicode(cells[0].text_content())
+                desc = force_unicode(cells[-1].text_content())
                 label = "Docket Text: "
                 if desc.startswith(label):
                     desc = desc[len(label) :]
@@ -207,6 +216,14 @@ class DocketHistoryReport(DocketReport):
             if m:
                 return convert_date_string(m.group(1))
 
+    def _get_date_entered(self, cell):
+        s = clean_string(cell.text_content())
+        regexes = [self.date_entered_regex, self.date_filed_and_entered_regex]
+        for regex in regexes:
+            m = regex.search(s)
+            if m:
+                return convert_date_string(m.group(1))
+
     def _set_metadata_values(self):
         text_nodes = self.tree.xpath("//center[not(.//table)]//text()")
         values = []
@@ -231,7 +248,7 @@ class DocketHistoryReport(DocketReport):
         matches = set()
         # Skip the last value, it's a concat of all previous values and
         # isn't needed for case name matching.
-        for prev, v, nxt in previous_and_next(self.metadata_values[:-1]):
+        for prev, v, _nxt in previous_and_next(self.metadata_values[:-1]):
             if prev is None:
                 continue
             for regex in regexes:
@@ -249,7 +266,17 @@ class DocketHistoryReport(DocketReport):
             case_name = "Unknown Case Title"
         return harmonize(case_name)
 
-    def _get_docket_number(self):
+    def _parse_docket_number(
+        self,
+    ) -> tuple[Union[str, None], dict[str, Union[str, None]]]:
+        """Parse a valid docket number and its components.
+
+        :param: docket_number: A string docket number to clean.
+        :return :return: A two-tuple: the docket_number and a dict containing the
+        docket_number components if a valid docket number was found.
+        Otherwise, None and the default docket_number components dict with None
+        values.
+        """
         if self.is_bankruptcy:
             # Uses both b/c sometimes the bankr. cases have a dist-style docket
             # number.
@@ -265,12 +292,15 @@ class DocketHistoryReport(DocketReport):
             for s in string_nodes:
                 match = regex.search(s)
                 if match:
-                    return match.group(1)
+                    docket_number_components = self._parse_dn_components(s)
+                    return match.group(1), docket_number_components
+
+        return None, self._return_default_dn_components()
 
     def _get_assigned_judge(self):
         if self.is_bankruptcy:
             # Look for string like "Judge: Michael J. Fox"
-            for prev, v, nxt in previous_and_next(self.metadata_values[:-1]):
+            for prev, v, _nxt in previous_and_next(self.metadata_values[:-1]):
                 if prev is not None and re.search("Judge:", prev, flags=re.I):
                     return normalize_judge_string(v)[0]
         else:
