@@ -2,31 +2,34 @@ import copy
 import pprint
 import re
 import sys
+from typing import Optional, Union
 
 from dateutil.tz import gettz
 from lxml import etree
+from lxml.etree import _ElementUnicodeResult
 from lxml.html import HtmlElement, fromstring, tostring
 
-from ..lib.judge_parsers import normalize_judge_string
-from ..lib.log_tools import make_default_logger
-from ..lib.string_utils import (
+from juriscraper.lib.judge_parsers import normalize_judge_string
+from juriscraper.lib.log_tools import make_default_logger
+from juriscraper.lib.string_utils import (
     clean_string,
     convert_date_string,
     force_unicode,
     harmonize,
 )
-from ..lib.utils import clean_court_object, previous_and_next
+from juriscraper.lib.utils import clean_court_object, previous_and_next
+
 from .docket_utils import normalize_party_types
 from .reports import BaseReport
 from .utils import (
+    get_file_size_str_from_tr,
+    get_input_value_from_tr,
     get_pacer_doc_id_from_doc1_url,
     get_pacer_seq_no_from_doc1_anchor,
 )
 
 logger = make_default_logger()
 
-date_regex = r"[—\d\-–/]+"
-
 
 class BaseDocketReport:
     """A small class to hold functions common to the InternetArchive report
@@ -37,11 +40,17 @@ class BaseDocketReport:
     little class as a mixin with the common components.
     """
 
+    # A date is one or more characters that are members of the class
+    # of endashes (U+2014), digits, ASCII dashes (U+002D), emdashes
+    # (U+2013), and ASCII slashes.
+    DATE_REGEX = r"[—\d\-–/]+"
+
+    date_entered_regex = re.compile(r"Entered:\s+(%s)" % DATE_REGEX)
     date_terminated_regex = re.compile(
-        r"[tT]erminated:\s+(%s)" % date_regex, flags=re.IGNORECASE
+        r"[tT]erminated:\s+(%s)" % DATE_REGEX, flags=re.IGNORECASE
     )
     docket_number_dist_regex = re.compile(
-        r"((\d{1,2}:)?\d\d-[a-zA-Z]{1,4}-\d{1,10})"
+        r"(?<!\d)((\d{1,2}:)?\d\d-[a-zA-Z]{1,5}-\d{1,10})"
     )
     docket_number_bankr_regex = re.compile(r"(?:#:\s+)?((\d-)?\d\d-\d*)")
     docket_number_jpml = re.compile(r"(MDL No.\s+\d*)")
@@ -81,6 +90,14 @@ class BaseDocketReport:
         for party in parties:
             for atty in party.get("attorneys", []):
                 if not atty["contact"]:
+                    # This scenario should not happen, and we lack a test for it, and it's
+                    # not clear how to write one or why this code is here; it was added in
+                    # a97ebf61c3cafa7589d3f9ddc0c65be23131f019.
+                    # We are not generally invoked with an attorney
+                    # dict that both contains a `contact` key and that
+                    # key has no value. If we're invoked with an empty
+                    # attorney dict, then this will throw a
+                    # ValueError.
                     continue
 
                 if re.search(r"see\s+above", atty["contact"], re.I):
@@ -144,15 +161,117 @@ class BaseDocketReport:
         else:
             return s
 
-    def _parse_docket_number_strs(self, potential_docket_numbers):
-        """Parse docket numbers from a list of potential ones
+    @staticmethod
+    def _return_default_dn_components() -> dict[str, Union[str, None]]:
+        """Return a dictionary with default values for the docket_number
+        components to return on non-valid docket_numbers.
+
+        :return: A dictionary containing the docket_number components with None
+        values.
+        """
+        return {
+            "federal_defendant_number": None,
+            "federal_dn_case_type": None,
+            "federal_dn_judge_initials_assigned": None,
+            "federal_dn_judge_initials_referred": None,
+            "federal_dn_office_code": None,
+        }
+
+    def _parse_dn_components(
+        self, potential_docket_number
+    ) -> dict[str, Union[str, None]]:
+        """Parse the potential docket number into its components.
+
+        :param potential_docket_number: The docket number string to be parsed.
+        :return: A dictionary with parsed components of the docket number.
+        If the docket_number is not valid returns default None values.
+        """
+
+        regex_district = (
+            r"(?:"  # District format: 3:20-cr-00070-TKW-MAL-1
+            r"(?P<federal_dn_office_code>\d):"
+            r"\d{2}-"
+            r"(?P<federal_dn_case_type>[a-zA-Z0-9]{1,5}|~gr)-"
+            r"\d{5}"
+            r"(?:-(?P<federal_dn_judge_initials_assigned>N\/A|P1|[a-zA-Z_]{1,5}))?"  # Optional: hyphen followed by 1-5 letters/underscores or N/A or P1
+            r"(?:-(?P<federal_dn_judge_initials_referred>[a-zA-Z_]{1,5}))?"  # Optional: another set of judge initials
+            r"(?:-(?P<federal_defendant_number>\d{1,3}))?"  # Optional: hyphen followed by up to 3 digits
+            r")"
+        )
+
+        regex_bankruptcy = (
+            r"(?:"
+            r"\d{2}-\d{5}-"  # Alternative format for bankruptcy: 10-01083-8-RDD
+            r"(?P<alternative_federal_dn_office_code>\d)-"
+            r"(?P<alternative_federal_dn_judge_initials_assigned>[a-zA-Z]{2,4})"
+            r"|"  # OR
+            r"(?:"  # Bankruptcy format: 3:20-cr-00070-TKW
+            r"(?P<federal_dn_office_code>\d):"
+            r"\d{2}-"
+            r"(?P<federal_dn_case_type>[a-zA-Z0-9]{1,5}|~gr)-"
+            r"\d{5}"
+            r"|"
+            r"(?:\d{2}-\d{5})"  # Alternative format for bankruptcy: 02-00017-LMK
+            r")"
+            r"(?:-(?P<federal_dn_judge_initials_assigned>N\/A|P1|[a-zA-Z_]{1,5}))?"  # Optional: hyphen followed by 1-5 letters/underscores or N/A or P1
+            r")"
+        )
+
+        match = re.search(regex_district, potential_docket_number)
+        if self.is_bankruptcy:
+            match = re.search(regex_bankruptcy, potential_docket_number)
+
+        if match:
+            # Clean up parsed components. Assign alternative_federal_dn_office_code
+            # and alternative_federal_dn_judge_initials_assigned to federal_dn_office_code and
+            # federal_dn_judge_initials_assigned if they match.
+            parsed_components = match.groupdict()
+            if parsed_components.get("alternative_federal_dn_office_code"):
+                parsed_components["federal_dn_office_code"] = (
+                    parsed_components["alternative_federal_dn_office_code"]
+                )
+                parsed_components["federal_dn_judge_initials_assigned"] = (
+                    parsed_components[
+                        "alternative_federal_dn_judge_initials_assigned"
+                    ]
+                )
+
+            return {
+                "federal_dn_office_code": parsed_components.get(
+                    "federal_dn_office_code"
+                ),
+                "federal_dn_case_type": parsed_components.get(
+                    "federal_dn_case_type"
+                ),
+                "federal_dn_judge_initials_assigned": parsed_components.get(
+                    "federal_dn_judge_initials_assigned"
+                ),
+                "federal_dn_judge_initials_referred": parsed_components.get(
+                    "federal_dn_judge_initials_referred"
+                ),
+                "federal_defendant_number": parsed_components.get(
+                    "federal_defendant_number"
+                ),
+            }
+
+        return self._return_default_dn_components()
+
+    def _parse_docket_number_strs(
+        self, potential_docket_numbers: list[_ElementUnicodeResult]
+    ) -> tuple[Union[str, None], dict[str, Union[str, None]]]:
+        """Parse docket numbers from a list of potential ones. Also parse
+        the docket number components.
 
         :param potential_docket_numbers: Potential docket number unicode
         objects
         :type potential_docket_numbers: list
-        :return: The correct docket number
-        :rtype: unicode
+        :return: A two-tuple: the docket_number and a dict containing the
+        docket_number components if a valid docket number was found.
+        Otherwise, None and the default docket_number components dict with None
+        values.
+        :rtype: Tuple
         """
+
         if self.is_bankruptcy:
             # Uses both b/c sometimes the bankr. cases have a dist-style docket
             # number.
@@ -166,7 +285,10 @@ class BaseDocketReport:
             for s in potential_docket_numbers:
                 match = regex.search(s)
                 if match:
-                    return match.group(1)
+                    docket_number_components = self._parse_dn_components(s)
+                    return match.group(1), docket_number_components
+
+        return None, self._return_default_dn_components()
 
     def get_datetime_from_tree(self, path, cast_to_date=False):
         """Parse a datetime from the XML located at node.
@@ -256,7 +378,7 @@ class BaseDocketReport:
         #     label = label.decode("utf-8")
 
         label = (
-            label.strip()
+            re.sub(r"[\s\n]+", " ", label.strip())
             .lower()
             .replace(" ", "_")
             .replace("\xa0", "_")  # Non-breaking space
@@ -298,13 +420,16 @@ class DocketReport(BaseDocketReport, BaseReport):
         in_re_regex,
         in_the_matter_regex,
     ]
-    date_filed_regex = re.compile(r"Date [fF]iled:\s+(%s)" % date_regex)
+    date_filed_regex = re.compile(
+        r"Date [fF]iled:\s+(%s)" % BaseDocketReport.DATE_REGEX
+    )
     date_converted_regex = re.compile(
-        r"Date [Cc]onverted:\s+(%s)" % date_regex
+        r"Date [Cc]onverted:\s+(%s)" % BaseDocketReport.DATE_REGEX
     )
     # Be careful this does not match "Joint debtor discharged" field.
     date_discharged_regex = re.compile(
-        r"(?:Date|Debtor)\s+[Dd]ischarged:\s+(%s)" % date_regex
+        r"(?:Date|Debtor)\s+[Dd]ischarged:\s+(%s)"
+        % BaseDocketReport.DATE_REGEX
     )
     assigned_to_regex = r"Assigned to:\s+(.*)"
     referred_to_regex = r"Referred to:\s+(.*)"
@@ -334,24 +459,23 @@ class DocketReport(BaseDocketReport, BaseReport):
     ERROR_STRINGS = BaseReport.ERROR_STRINGS + [
         "The report may take a long time to run because this case has many "
         "docket entries",
-        "The page ID does not exist. Please enter a valid page ID number. ",
-        "There are no documents in this case.",
-        "Incomplete request. Please try your query again by choosing the "
+        "The page ID does not exist\\. Please enter a valid page ID number\\. ",
+        "There are no documents in this case\\.",
+        "Incomplete request\\. Please try your query again by choosing the "
         "Query or Reports option",
         "To accept charges shown below, click on the 'View Report' button",
-        "Unable to create PDF file.",
-        "This case was administratively closed",
+        "\\*\\*\\* This case was administratively closed\\.\\*\\*\\*",
         "The start date must be less than or equal to the end date",
         "The starting document number must be less than or equal to the "
         "ending document number",
-        "Case not found.",
+        "Case not found\\.",
         "Either you do not have permission to view the document, or the "
-        "document does not exist in the case.",
+        "document does not exist in the case\\.",
         "Format: text",
-        "Server timeout waiting for the HTTP request from the client.",
+        "Server timeout waiting for the HTTP request from the client\\.",
         "The case type was.*but it must be",
         "This case is in the process of being opened, please check back later "
-        "for additional information.",
+        "for additional information\\.",
         "Submission already made, please wait for response from server",
     ]
 
@@ -435,9 +559,10 @@ class DocketReport(BaseDocketReport, BaseReport):
             return self._metadata
 
         self._set_metadata_values()
+        docket_number, docket_number_components = self._parse_docket_number()
         data = {
             "court_id": self.court_id,
-            "docket_number": self._get_docket_number(),
+            "docket_number": docket_number,
             "case_name": self._get_case_name(),
             "date_filed": self._get_value(
                 self.date_filed_regex, self.metadata_values, cast_to_date=True
@@ -471,7 +596,11 @@ class DocketReport(BaseDocketReport, BaseReport):
             "mdl_status": self._get_value(
                 self.mdl_status_regex, self.metadata_values
             ),
+            "ordered_by": self._get_docket_entries_order(),
         }
+        # Include the docket_number components.
+        data.update(docket_number_components)
+
         data = clean_court_object(data)
         self._metadata = data
         return data
@@ -541,8 +670,7 @@ class DocketReport(BaseDocketReport, BaseReport):
                 continue
 
             name_path = (
-                ".//b[not(./parent::i)][not(./u)]"
-                '[not(contains(., "------"))]'
+                './/b[not(./parent::i)][not(./u)][not(contains(., "------"))]'
             )
             is_party_name_cell = len(cells[0].xpath(name_path)) > 0
             prev_has_disposition = (
@@ -708,7 +836,7 @@ class DocketReport(BaseDocketReport, BaseReport):
         }
         current_party_i = -1
         criminal_data = copy.deepcopy(empty_criminal_data)
-        for prev, row, nxt in previous_and_next(party_rows):
+        for _prev, row, nxt in previous_and_next(party_rows):
             cells = row.xpath(".//td")
             if len(cells) == 0:
                 # Empty row. Press on.
@@ -914,12 +1042,9 @@ class DocketReport(BaseDocketReport, BaseReport):
                 "contact": "",
             }
             path = "./following-sibling::* | ./following-sibling::text()"
-            for prev, node, nxt in previous_and_next(atty_node.xpath(path)):
+            for _prev, node, nxt in previous_and_next(atty_node.xpath(path)):
                 # noinspection PyProtectedMember
-                if isinstance(
-                    node,
-                    (etree._ElementStringResult, etree._ElementUnicodeResult),
-                ):
+                if isinstance(node, etree._ElementUnicodeResult):
                     clean_atty = "%s\n" % " ".join(
                         n.strip() for n in node.split()
                     )
@@ -944,11 +1069,26 @@ class DocketReport(BaseDocketReport, BaseReport):
 
         return attorneys
 
-    @property
-    def docket_entries(self):
-        if self._docket_entries is not None:
-            return self._docket_entries
+    def _get_docket_entries_order(self) -> Optional[str]:
+        """Get the order of entries in the docket sheet."""
 
+        docket_entry_all_rows = self._get_docket_entry_rows()
+        try:
+            docket_entry_table_headers = docket_entry_all_rows[0]
+            header_cells = docket_entry_table_headers.xpath(
+                "./td[not(./input)] | ./th[not(./input)]"
+            )
+            order = "date_filed"
+            if header_cells[0].text_content() in [
+                "Date Entered",
+                "Docket Date",
+            ]:
+                order = "date_entered"
+        except IndexError:
+            return None
+        return order
+
+    def _get_docket_entry_rows(self) -> list[HtmlElement]:
         # There can be multiple docket entry tables on a single docket page.
         # See https://github.com/freelawproject/courtlistener/issues/762. ∴ we
         # need to identify the first table, and all following tables. The
@@ -960,24 +1100,264 @@ class DocketReport(BaseDocketReport, BaseReport):
             'selected documents")])'
         )
         footer_multi_doc = 'not(.//text()[contains(., "Footer format:")])'
-        docket_entry_rows = self.tree.xpath(
+        docket_entry_all_rows = self.tree.xpath(
             "//table"
-            "[preceding-sibling::table[{dh}] or {dh}]"
-            "[{b_multi_doc}]"
-            "[{footer_multi_doc}]"
-            "/tbody/tr".format(
-                dh=docket_header,
-                b_multi_doc=bankr_multi_doc,
-                footer_multi_doc=footer_multi_doc,
-            )
-        )[
-            1:
-        ]  # Skip the first row.
+            f"[preceding-sibling::table[{docket_header}] or {docket_header}]"
+            f"[{bankr_multi_doc}]"
+            f"[{footer_multi_doc}]"
+            "/tbody/tr"
+        )
+        return docket_entry_all_rows
 
+    def _get_attachment_number(self, row):
+        """Return the attachment number for an item.
+
+        In district courts, this can be easily extracted. In bankruptcy courts,
+        you must extract it, then subtract 1 from the value since these are
+        tallied and include the main document.
+        """
+        number = int(row.xpath(".//td/text()")[0].strip())
+        return number
+
+    def _get_description_from_tr(self, row):
+        """Get the description from the row"""
+        if not self.is_bankruptcy:
+            index = 2
+            # Some NEFs attachment pages for some courts have an extra column
+            # (see nyed_123019137279), use index 3 to get the description
+            columns_in_row = row.xpath("./td")
+            if len(columns_in_row) == 5:
+                index = 3
+        else:
+            index = 3
+
+        description_text_nodes = row.xpath(f"./td[{index}]//text()")
+        if not description_text_nodes:
+            # No text in the cell.
+            return ""
+        description = description_text_nodes[0].strip()
+        return force_unicode(description)
+
+    @staticmethod
+    def _get_de_arr_de_seq_nums_sequence(td):
+        """Get the docket entry row sequence number."""
+        try:
+            input = td.xpath(".//input[@name='arr_de_seq_nums']")[0]
+        except IndexError:
+            return None
+        else:
+            # initial value string "arr_de_seq_nums_2"
+            # "2" is sequence
+            id_path = input.xpath("./@id")
+            id_value = None
+            if id_path:
+                id_value = id_path[0].removeprefix("arr_de_seq_nums_")
+            value = input.xpath("./@value")[0]
+            if id_value is not None and id_value != value:
+                return None
+            return value
+
+    @staticmethod
+    def _get_attachment_id_value_from_tr(tr, idx):
+        """Take a row from the attachment table and return the id value by
+        index.
+        """
+        try:
+            input = tr.xpath(".//input[@name='download_documents']")[0]
+        except IndexError:
+            return None
+        else:
+            # initial value string "arr_de_seq_nums_2_90555"
+            # "90555" is size in bytes "2" is sequence
+            value = input.xpath("./@id")[0].removeprefix("arr_de_seq_nums_")
+            split_value = value.split("_")
+            if len(split_value) != 2:
+                return None
+            return split_value[idx]
+
+    @staticmethod
+    def _get_page_count_from_tr_input_value(tr):
+        """Take a row from the attachment table and return the page count as an
+        int extracted from the input value.
+        """
+        count = get_input_value_from_tr(tr, 2, 3, "-")
+        if count is not None:
+            return int(count)
+
+    @staticmethod
+    def _get_page_count_from_tr(tr):
+        """Take a row from the attachment table and return the page count as an
+        int extracted from the cell specified by index.
+        """
+        pg_cnt_input = DocketReport._get_page_count_from_tr_input_value(tr)
+        if pg_cnt_input:
+            return pg_cnt_input
+        pg_cnt_str_nodes = tr.xpath('./td[contains(., "page")]/text()')
+        if not pg_cnt_str_nodes:
+            # It's a restricted document without page count information.
+            return None
+
+        for pg_cnt_str_node in pg_cnt_str_nodes:
+            try:
+                pg_cnt_str = pg_cnt_str_node.strip()
+                return int(pg_cnt_str.split()[0])
+            except ValueError:
+                # Happens when the description field contains the
+                # word "page" and gets caught by the xpath. Just
+                # press on.
+                continue
+
+    @staticmethod
+    def _get_file_size_bytes_from_tr(tr):
+        """Take a row from the attachment table and return the number of bytes
+        as an int.
+        """
+        download_documents = tr.xpath(".//input[@name='download_documents']")
+        if download_documents:
+            file_size_str = DocketReport._get_attachment_id_value_from_tr(
+                tr, 1
+            )
+        else:
+            file_size_str = get_input_value_from_tr(tr, 1, 3, "-")
+        if file_size_str is None:
+            return None
+        file_size = int(file_size_str)
+        if file_size == 0:
+            return None
+        return file_size
+
+    def _get_pacer_doc_id(self, row):
+        """Take in a row from the attachment table and return the pacer_doc_id
+        for the item in that row. Return None if the ID cannot be found.
+        Calculate the doc_id by extracting the first part of the value string
+        which is the doc_id suffix and combining it with the doc_id prefix
+        which is computed using a lookup table from the court_id. Insert a 0
+        between the prefix and suffix to normalize the doc_id to the attachment
+        page variant.
+        """
+        # we get our doc_id suffix "23515655"
+        download_documents = row.xpath(".//input[@name='download_documents']")
+        pacer_doc_suffix = None
+        if download_documents:
+            value = download_documents[0].xpath("./@value")
+            if value:
+                pacer_doc_suffix = value[0]
+        else:
+            pacer_doc_suffix = get_input_value_from_tr(row, 0, 3, "-")
+        if pacer_doc_suffix is None:
+            return None
+        # after inserting prefixes our final doc_id is "035023515655"
+        return f"{self.doc_id_prefix}0{pacer_doc_suffix}"
+
+    @staticmethod
+    def _get_pacer_seq_no_from_tr(row):
+        """Take a row of the attachment table, and return the sequence number
+        from the name attribute.
+        """
+        try:
+            input = row.xpath(".//input")[0]
+        except IndexError:
+            # No link in the row. Maybe its sealed.
+            pass
+        else:
+            try:
+                name = input.xpath("./@name")[0]
+            except IndexError:
+                # No onclick on this row.
+                pass
+            else:
+                if name == "download_documents":
+                    return DocketReport._get_attachment_id_value_from_tr(
+                        row, 0
+                    )
+                return name.split("_")[2]
+
+        return None
+
+    def _get_attachments(self, cells):
+        rows = cells.xpath("./table//tr")
+
+        result = []
+        for row in rows:
+            attachment = {
+                "attachment_number": self._get_attachment_number(row),
+                "description": self._get_description_from_tr(row),
+                "page_count": self._get_page_count_from_tr(row),
+                "file_size_str": get_file_size_str_from_tr(row),
+                "pacer_doc_id": self._get_pacer_doc_id(row),
+                # It may not be needed to reparse the seq_no
+                # for each row, but we may as well. So far, it
+                # has always been the same as the main document.
+                "pacer_seq_no": self._get_pacer_seq_no_from_tr(row),
+            }
+            file_size_bytes = self._get_file_size_bytes_from_tr(row)
+            if file_size_bytes is not None:
+                attachment["file_size_bytes"] = file_size_bytes
+            result.append(attachment)
+        return result
+
+    @staticmethod
+    def _de_matches_attachment(de, attachment):
+        return (
+            de["pacer_doc_id"] == attachment["pacer_doc_id"]
+            and de["pacer_seq_no"] == attachment["pacer_seq_no"]
+        )
+
+    @staticmethod
+    def _merge_de_with_attachment(de, attachment):
+        """Combines the attachment entry data corresponding with the docket
+        entry data. This should be the attachment with an attachment number
+        of 0. Additionally validates the doc_id and seq_no match before
+        merging the data.
+        """
+        if de["pacer_doc_id"] != attachment["pacer_doc_id"]:
+            raise ValueError(
+                f"docket entry doc_id {de['pacer_doc_id']} does not match "
+                f"attachment 0 doc_id {attachment['pacer_doc_id']}"
+            )
+        if de["pacer_seq_no"] != attachment["pacer_seq_no"]:
+            raise ValueError(
+                f"docket entry seq_no {de['pacer_seq_no']} does not match "
+                f"attachment 0 seq_no {attachment['pacer_seq_no']}"
+            )
+        de["file_size_bytes"] = attachment["file_size_bytes"]
+        de["file_size_str"] = attachment["file_size_str"]
+        de["page_count"] = attachment["page_count"]
+
+    @property
+    def docket_entries(self):
+        if self._docket_entries is not None:
+            return self._docket_entries
+
+        docket_entry_all_rows = self._get_docket_entry_rows()
+        docket_entry_rows = docket_entry_all_rows[1:]  # Skip the first row.
+
+        # Detect if the report was generated with "View multiple documents"
+        # option enabled.
+        view_multiple_documents = False
+        view_multi_docs = self.tree.xpath("//form[@name='view_multi_docs']")
+        if view_multi_docs:
+            view_multiple_documents = True
         docket_entries = []
         for row in docket_entry_rows:
             de = {}
             cells = row.xpath("./td[not(./input)]")
+
+            # If view_multiple_documents report, remove the "checkbox" cell on
+            # rows that lack a checkbox, as observed in sealed documents.
+            if view_multiple_documents and len(cells) == 4:
+                # In bankruptcy reports, there is an additional cell preceding
+                # the entry number which will be removed later. For now avoid
+                # removing the entry number in index [2]. See alnb_1.html.
+                cell_2_value = cells[2].text_content().strip()
+                if not cell_2_value:
+                    # This is the empty "checkbox" cell, remove it. See dcd_3.html
+                    del cells[2]
+            if view_multiple_documents and len(cells) == 5:
+                # In bankruptcy reports for entries that do not have a checkbox,
+                #  remove the empty "checkbox" cell. See alnb_1.html.
+                del cells[3]
+
             if len(cells) == 0:
                 # In some instances, the document entry table has an empty row
                 # <tr></tr>. See docket bankruptcy wiwb examples.
@@ -989,15 +1369,42 @@ class DocketReport(BaseDocketReport, BaseReport):
 
             date_filed_str = force_unicode(cells[0].text_content())
             if not date_filed_str.strip():
+                if view_multiple_documents and len(cells) >= 3:
+                    last_de = docket_entries[-1]
+                    attachments = self._get_attachments(cells[2])
+                    for idx, attachment in enumerate(attachments):
+                        if self._de_matches_attachment(last_de, attachment):
+                            self._merge_de_with_attachment(last_de, attachment)
+                            if (
+                                idx == 0
+                                and attachment["attachment_number"] == 0
+                            ):
+                                attachments.pop(idx)
+                        elif (
+                            last_de["pacer_seq_no"]
+                            != attachment["pacer_seq_no"]
+                        ):
+                            raise ValueError(
+                                f"docket entry seq_no {last_de['pacer_seq_no']} does not "
+                                f"match attachment seq_no {attachment['pacer_seq_no']}"
+                            )
+                    if len(attachments) > 0:
+                        last_de["attachments"] = attachments
                 # Some older dockets have missing dates. Press on.
                 continue
             de["date_filed"] = convert_date_string(date_filed_str)
             de["document_number"] = self._get_document_number(cells[1])
-            results = self._get_pacer_doc_id_and_seq_no(
+            pacer_doc_id, pacer_seq_no = self._get_pacer_doc_id_and_seq_no(
                 cells[1], de["document_number"]
             )
-            de["pacer_doc_id"], de["pacer_seq_no"] = results[0], results[1]
+            de["pacer_doc_id"] = pacer_doc_id
+            if pacer_seq_no is None:
+                pacer_seq_no = self._get_de_arr_de_seq_nums_sequence(row)
+            de["pacer_seq_no"] = pacer_seq_no
             de["description"] = self._get_description(cells)
+            de["date_entered"] = self._get_value(
+                self.date_entered_regex, de["description"], cast_to_date=True
+            )
 
             number = de["document_number"]
             if number is not None and not number.isdigit():
@@ -1065,12 +1472,12 @@ class DocketReport(BaseDocketReport, BaseReport):
         self.parse()
         """
         # Set up and sanity tests
-        assert (
-            self.session is not None
-        ), "session attribute of DocketReport cannot be None."
-        assert bool(
-            pacer_case_id
-        ), f"pacer_case_id must be truthy, not '{pacer_case_id}'"
+        assert self.session is not None, (
+            "session attribute of DocketReport cannot be None."
+        )
+        assert bool(pacer_case_id), (
+            f"pacer_case_id must be truthy, not '{pacer_case_id}'"
+        )
 
         if date_range_type not in ["Filed", "Entered"]:
             raise ValueError("Invalid value for 'date_range_type' parameter.")
@@ -1099,7 +1506,7 @@ class DocketReport(BaseDocketReport, BaseReport):
             # Any value works in this parameter, but it cannot be blank.
             # Normally this would have a value like '3:12-cv-3879', but that's
             # not even necessary.
-            "case_num": " "
+            "case_num": " ",
             # These fields seem to be unnecessary/unused.
             # 'view_comb_doc_text': '',
             # 'PreResetField': '',
@@ -1145,7 +1552,8 @@ class DocketReport(BaseDocketReport, BaseReport):
         # The first ancestor table of the table cell containing "date filed"
         table = self.tree.xpath(
             # Match any td containing Date [fF]iled
-            '//td[.//text()[contains(translate(., "f", "F"), "Date Filed:")]]'
+            '//td[.//text()[contains(translate(., "f", "F"), "Date Filed:") '
+            'or contains(translate(., "d", "D"), "Filed Date:")]]'
             # And find its highest ancestor table that lacks a center tag.
             "/ancestor::table[not(.//center)][last()]"
         )[0]
@@ -1192,7 +1600,7 @@ class DocketReport(BaseDocketReport, BaseReport):
             word for phrase in self._br_split(cell) for word in phrase.split()
         ]
         if words:
-            first_word = re.sub("[\\s\u00A0]", "", words[0])
+            first_word = re.sub("[\\s\u00a0]", "", words[0])
             if self.court_id == "txnb":
                 # txnb merges the second and third columns, so if the first
                 # word is a number, return it. Otherwise, assume doc number
@@ -1212,7 +1620,7 @@ class DocketReport(BaseDocketReport, BaseReport):
         # combined. The field can have one of four formats. Attempt the most
         # detailed first, then work our way down to just giving up and
         # capturing it all.
-        ws = "[\\s\u00A0]"  # Whitespace including nbsp
+        ws = "[\\s\u00a0]"  # Whitespace including nbsp
         regexes = [
             # 2 (23 pgs; 4 docs) Blab blah (happens when attachments exist and
             # page numbers are on)
@@ -1286,9 +1694,18 @@ class DocketReport(BaseDocketReport, BaseReport):
 
         return clean_string(harmonize(case_name))
 
-    def _get_docket_number(self):
+    def _parse_docket_number(
+        self,
+    ) -> tuple[Union[str, None], dict[str, Union[str, None]]]:
+        """Parse a valid docket number and its components.
+
+        :return: A two-tuple: the docket_number and a dict containing the
+        docket_number components if a valid docket number was found.
+        Otherwise, None and the default docket_number components dict with None
+        values.
+        """
         if self.is_bankruptcy:
-            docket_number_path = "//font"
+            docket_number_path = "//center//font"
         else:
             docket_number_path = "//h3"
         nodes = self.tree.xpath(docket_number_path)
