@@ -1,22 +1,28 @@
 import re
-from typing import Optional, Tuple
+from typing import Optional
 from urllib.parse import urljoin
 
 import requests
 from lxml.html import HtmlElement
 from requests import Response
 
-from ..lib.html_utils import (
+from juriscraper.lib.html_utils import (
     clean_html,
     fix_links_in_lxml_tree,
-    get_html5_parsed_text,
     get_html_parsed_text,
     is_html,
     set_response_encoding,
     strip_bad_html_tags_insecure,
 )
-from ..lib.log_tools import make_default_logger
-from .utils import is_pdf, make_doc1_url, make_docs1_url
+from juriscraper.lib.log_tools import make_default_logger
+
+from .utils import (
+    get_doc_id_prefix_from_court_id,
+    is_pdf,
+    make_acms_free_doc_url,
+    make_doc1_url,
+    make_docs1_url,
+)
 
 logger = make_default_logger()
 
@@ -54,6 +60,10 @@ class BaseReport:
         self.response = None
         self.is_valid = None
 
+    @property
+    def doc_id_prefix(self):
+        return get_doc_id_prefix_from_court_id(self.court_id)
+
     @property
     def url(self):
         if self.court_id == "psc":
@@ -87,9 +97,9 @@ class BaseReport:
         :param text: A unicode object
         :return: None
         """
-        assert isinstance(
-            text, str
-        ), f"Input must be unicode, not {type(text)}"
+        assert isinstance(text, str), (
+            f"Input must be unicode, not {type(text)}"
+        )
         text = clean_html(text)
         self.check_validity(text)
         if self.is_valid:
@@ -131,7 +141,8 @@ class BaseReport:
         pacer_doc_id: str,
         pacer_magic_num: Optional[str],
         got_receipt: str,
-    ) -> Tuple[Response, str]:
+        de_seq_num: Optional[str] = None,
+    ) -> tuple[Response, str]:
         """Query the doc1 download URL.
 
         :param pacer_case_id: The ID of the case
@@ -172,6 +183,9 @@ class BaseReport:
         if pacer_magic_num is not None:
             data["magic_num"] = pacer_magic_num
 
+        if de_seq_num:
+            data["de_seq_num"] = de_seq_num
+
         timeout = (60, 300)
         logger.info(f"POSTing URL: {url} with params: {data}")
         r = self.session.post(url, data=data, timeout=timeout)
@@ -179,11 +193,13 @@ class BaseReport:
 
     def download_pdf(
         self,
-        pacer_case_id: str,
-        pacer_doc_id: int,
+        pacer_case_id: Optional[str] = None,
+        pacer_doc_id: Optional[int] = None,
         pacer_magic_num: Optional[str] = None,
         appellate: bool = False,
-    ) -> Tuple[Optional[Response], str]:
+        de_seq_num: Optional[str] = None,
+        acms: bool = False,
+    ) -> tuple[Optional[Response], str]:
         """Download a PDF from PACER.
 
         Note that this doesn't support attachments yet.
@@ -192,15 +208,22 @@ class BaseReport:
         one can be found (is not sealed, gone, etc.). And a string indicating
         the error message, if there is one or else an empty string.
         """
+
+        assert acms or (pacer_case_id and pacer_doc_id), (
+            "pacer_case_id and pacer_doc_id can't be None for non-ACMS downloads."
+        )
+
         if pacer_magic_num:
             # If magic_number is available try to download the
             # document anonymously by its magic link
 
             # Create PACER base url from court_id and pacer_doc_id
             # Magic link parameters
-            # We don't need the de_seq_num parameter to fetch the free document
-            if appellate:
-                url = make_docs1_url(self.court_id, pacer_doc_id, True)
+            if acms:
+                url = make_acms_free_doc_url(self.court_id, pacer_magic_num)
+                params = {}
+            elif appellate:
+                url = make_docs1_url(self.court_id, str(pacer_doc_id), True)
                 # For appellate documents the magic_number is the uid param
                 params = {
                     "uid": pacer_magic_num,
@@ -210,8 +233,12 @@ class BaseReport:
                 params = {
                     "caseid": pacer_case_id,
                     "magic_num": pacer_magic_num,
+                    "use_magic": "1",  # Bypass the free look confirmation.
                 }
 
+            if de_seq_num:
+                params["de_seq_num"] = de_seq_num
+
             # Add parameters to the PACER base url and make a GET request
             req_timeout = (60, 300)
             r = requests.get(url, params=params, timeout=req_timeout)
@@ -232,7 +259,11 @@ class BaseReport:
         else:
             # If no magic_number use normal method to fetch the document
             r, url = self._query_pdf_download(
-                pacer_case_id, pacer_doc_id, pacer_magic_num, got_receipt="1"
+                pacer_case_id,
+                pacer_doc_id,
+                pacer_magic_num,
+                got_receipt="1",
+                de_seq_num=de_seq_num,
             )
 
             # Use r.content instead of r.text for performance. See #564
@@ -246,6 +277,13 @@ class BaseReport:
                 )
 
             error = None
+            if b"Cannot locate the case with caseid" in r.content:
+                # Second download attempt failed. log case ID and URL for
+                # debugging
+                error = (
+                    f"Cannot locate the case with caseid: "
+                    f"{pacer_case_id} at {url}"
+                )
             if b"could not retrieve dktentry for dlsid" in r.content:
                 error = (
                     f"Failed to get docket entry in case: "
@@ -271,12 +309,27 @@ class BaseReport:
                 )
             if b"You do not have access to this transcript." in r.content:
                 error = f"Unable to get transcript. {pacer_case_id=}, {url=}"
-            if b"Sealed Document" in r.content or b"Under Seal" in r.content:
+
+            if b"No matter of public record" in r.content:
+                error = (
+                    f"No matter of public record has been filed. "
+                    f"{pacer_case_id=}, {url=}"
+                )
+            sealed_document_phrases = [
+                b"Sealed Document",
+                b"Under Seal",
+                b"Document is Sealed",
+                b"This document is SEALED",
+            ]
+            if any(phrase in r.content for phrase in sealed_document_phrases):
                 # See: https://ecf.almd.uscourts.gov/doc1/01712589088
                 # See: https://ecf.cand.uscourts.gov/doc1/035122021132
+                # See: https://ecf.caed.uscourts.gov/doc1/03319001890
                 # Matches against:
-                # "Sealed Document" and
+                # "Sealed Document"
                 # "This document is currently Under Seal and not available..."
+                # "Document is Sealed."
+                # "This document is SEALED"
                 error = f"Document is sealed: {pacer_case_id=} {url=}"
             if (
                 b"This image is not available for viewing by non-court users"
@@ -370,3 +423,17 @@ class BaseReport:
         )
         sealed = "You do not have permission to view this document."
         return sealed in r.content
+
+    def is_entry_sealed(
+        self,
+        pacer_case_id: str,
+        pacer_doc_id: str,
+        pacer_magic_num: Optional[str] = None,
+    ):
+        """Check if a docket entry is sealed without trying to actually download
+        it.
+        """
+        r, url = self._query_pdf_download(
+            pacer_case_id, pacer_doc_id, pacer_magic_num, got_receipt="0"
+        )
+        return b"could not retrieve dktentry for dlsid" in r.content
